/* 
 * @file
 * @author Amr Hassan <amr.hassan@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <sqlite3.h>
#include "Connection.hpp"
#include "Statement.hpp"
#include "Exception.hpp"
#include "rogue_private.hpp"

class ConnectionDeleter
{
public:
	void operator()(sqlite3* object) {
		sqlite3_close(object);
	}
};

sqlite3pp::Connection::Connection(const std::string& uri)
{
	sqlite3* st;
	int resultCode = sqlite3_open(uri.c_str(), &st);

	checkResultCode(resultCode, internalObject.get());

	internalObject = boost::shared_ptr<sqlite3>(st, ConnectionDeleter());
}

sqlite3pp::Statement sqlite3pp::Connection::createStatement(const std::string& sql)
{
	return Statement(*this, sql);
}

void sqlite3pp::Connection::execute(const std::string& sql)
{
	Statement(*this, sql).execute();
}
