/* 
 * @file
 * @author Amr Hassan <amr.hassan@gmail.com>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <sqlite3.h>
#include "rogue_private.hpp"
#include "Connection.hpp"

void sqlite3pp::checkResultCode(int resultCode, sqlite3* connectionObject)
{
	switch (resultCode)
	{
	case SQLITE_OK:
		return;

	case SQLITE_ERROR:
		throw Exception(std::string("FATAL ERROR: ") +
				std::string(sqlite3_errmsg(connectionObject)));

	case SQLITE_INTERNAL:
		throw Exception("Internal logic error");

	case SQLITE_PERM:
		throw Exception("Access permission denied");

	case SQLITE_ABORT:
		throw Exception("Callback routine requested an abort");

	case SQLITE_BUSY:
		throw Exception("The database is locked");

	case SQLITE_LOCKED:
		throw Exception("A table in the database is locked");

	case SQLITE_NOMEM:
		throw Exception("Memory allocation failed");

	case SQLITE_READONLY:
		throw Exception("Attempting to write to a read-only database");

	case SQLITE_INTERRUPT:
		throw Exception("Opreation terminated by sqlite3_interrupt()");

	case SQLITE_IOERR:
		throw Exception("Disk I/O error");

	case SQLITE_CORRUPT:
		throw Exception("Database disk image is malformed");

	case SQLITE_NOTFOUND:
		throw Exception("Unknown opcode in sqlite3_file_control()");

	case SQLITE_FULL:
		throw Exception("Database is full");

	case SQLITE_CANTOPEN:
		throw Exception("Can't open the database file");

	case SQLITE_PROTOCOL:
		throw Exception("Datbase lock protocol error");

	case SQLITE_EMPTY:
		throw Exception("Database is empty");

	case SQLITE_SCHEMA:
		throw Exception("The database schema has changed");

	case SQLITE_TOOBIG:
		throw Exception("String or BLOB exceedsd size limit");

	case SQLITE_CONSTRAINT:
		throw Exception("Abort due to constraint violation");

	case SQLITE_MISMATCH:
		throw Exception("Data type mismatch");

	case SQLITE_MISUSE:
		throw Exception("Library used incorrectly");

	case SQLITE_NOLFS:
		throw Exception("OS features are not supported by host");

	case SQLITE_AUTH:
		throw Exception("Authorization denied");

	case SQLITE_FORMAT:
		throw Exception("Auxiliary database format error");

	case SQLITE_RANGE:
		throw Exception("2nd parameter to sqlite3_bind out of range");

	case SQLITE_NOTADB:
		throw Exception("File opened that is not a database");
	}
}




